@@ -1,15 +1,17 @@
 """这是westerLee111.py模块，提供了一个名为print_lol()的函数，这个函数的作用是
 打印列表，其中有可能包含（也有可能不包含）嵌套列表。"""
 
-def print_lol(the_list,level=0):
+def print_lol(the_list,indent=False,level=0):
     """这个函数取一个位置参数，名为“the_list”这可以是任何python
     列表（也可以是包含嵌套列表的列表）。所指定的列表中的每个数据项
     会（递归地）输出到屏幕上，各数据项各占一行。
-    第二个参数（名为level)用来在遇到嵌套列表时插入制表符。"""
+    第二个参数用来控制在默认情况下不打开缩进特性
+    第三个参数（名为level)用来在遇到嵌套列表时插入制表符。"""
     for each_item in the_list:
         if isinstance(each_item,list):
-            print_lol(each_item,level+1)
+            print_lol(each_item,indent,level+1)
         else:
-            for tab_stop in range(level):
-                print("\t",end="")
+            if indent:
+                for tab_stop in range(level):
+                    print("\t",end="")
             print(each_item)
\ No newline at end of file
